@@ -6,9 +6,10 @@ from dotenv import load_dotenv
 from rich import print as rprint
 
 import sql_cli
-from sql_cli.connections import convert_to_connection, validate_connections
+from sql_cli.connections import validate_connections
 from sql_cli.constants import DEFAULT_AIRFLOW_HOME, DEFAULT_DAGS_FOLDER
 from sql_cli.dag_generator import generate_dag
+from sql_cli.exceptions import EmptyDag, SqlFilesDirectoryNotFound
 from sql_cli.project import Project
 from sql_cli.run_dag import run_dag
 from sql_cli.utils.airflow import (
@@ -18,7 +19,7 @@ from sql_cli.utils.airflow import (
 )
 
 load_dotenv()
-app = typer.Typer(add_completion=False)
+app = typer.Typer(add_completion=False, context_settings={"help_option_names": ["-h", "--help"]})
 
 
 def set_logger_level(log_level: int) -> None:
@@ -26,7 +27,7 @@ def set_logger_level(log_level: int) -> None:
         logging.getLogger(name).setLevel(log_level)
 
 
-set_logger_level(logging.ERROR)
+set_logger_level(logging.CRITICAL)
 
 
 @app.command(help="Print the SQL CLI version.")
@@ -58,10 +59,17 @@ def generate(
     project = Project(project_dir_absolute)
     project.load_config(env)
 
-    dag_file = generate_dag(
-        directory=project.directory / project.workflows_directory / workflow_name,
-        dags_directory=project.airflow_dags_folder,
-    )
+    try:
+        dag_file = generate_dag(
+            directory=project.directory / project.workflows_directory / workflow_name,
+            dags_directory=project.airflow_dags_folder,
+        )
+    except EmptyDag:
+        rprint("[bold red]The workflow does not have any SQL files![/bold red]")
+        raise typer.Exit(code=1)
+    except SqlFilesDirectoryNotFound:
+        rprint("[bold red]A workflow with the given name does not exist![/bold red]")
+        raise typer.Exit(code=1)
     rprint("The DAG file", dag_file.resolve(), "has been successfully generated. 🎉")
 
 
@@ -85,8 +93,16 @@ def validate(
 ) -> None:
     project_dir_absolute = project_dir.resolve() if project_dir else Path.cwd()
     project = Project(project_dir_absolute)
+    project.load_config(environment=env)
 
-    validate_connections(project=project, environment=env, connection_id=connection)
+    # Since we are using the Airflow ORM to interact with connections, we need to tell Airflow to use our airflow.db
+    # The usual route is to set $AIRFLOW_HOME before Airflow is imported. However, in the context of the SQL CLI, we
+    # decide this during runtime, depending on the project path and SQL CLI configuration.
+    airflow_meta_conn = retrieve_airflow_database_conn_from_config(project.directory / project.airflow_home)
+    set_airflow_database_conn(airflow_meta_conn)
+
+    rprint(f"Validating connection(s) for environment '{env}'")
+    validate_connections(connections=project.connections, connection_id=connection)
 
 
 @app.command(
@@ -116,20 +132,34 @@ def run(
     project.update_config(environment=env)
     project.load_config(env)
 
-    connections = {c["conn_id"]: convert_to_connection(c) for c in project.connections}
-
     # Since we are using the Airflow ORM to interact with connections, we need to tell Airflow to use our airflow.db
     # The usual route is to set $AIRFLOW_HOME before Airflow is imported. However, in the context of the SQL CLI, we
     # decide this during runtime, depending on the project path and SQL CLI configuration.
     airflow_meta_conn = retrieve_airflow_database_conn_from_config(project.directory / project.airflow_home)
     set_airflow_database_conn(airflow_meta_conn)
 
-    dag_file = generate_dag(
-        directory=project.directory / project.workflows_directory / workflow_name,
-        dags_directory=project.airflow_dags_folder,
-    )
+    try:
+        dag_file = generate_dag(
+            directory=project.directory / project.workflows_directory / workflow_name,
+            dags_directory=project.airflow_dags_folder,
+        )
+    except EmptyDag:
+        rprint("[bold red]The workflow does not have any SQL files![/bold red]")
+        raise typer.Exit(code=1)
+    except SqlFilesDirectoryNotFound:
+        rprint("[bold red]A workflow with the given name does not exist![/bold red]")
+        raise typer.Exit(code=1)
     dag = get_dag(dag_id=workflow_name, subdir=dag_file.parent.as_posix(), include_examples=False)
-    run_dag(dag, run_conf=project.airflow_config, connections=connections, verbose=verbose)
+    rprint(f"\nRunning the workflow [bold blue]{dag.dag_id}[/bold blue] for [bold]{env}[/bold] environment\n")
+    dr = run_dag(
+        dag,
+        run_conf=project.airflow_config,
+        connections={c.conn_id: c for c in project.connections},
+        verbose=verbose,
+    )
+    rprint(f"Completed running the workflow {dr.dag_id}: [bold yellow][{dr.state.upper()}][/bold yellow]")
+    elapsed_seconds = (dr.end_date - dr.start_date).microseconds / 10**6
+    rprint(f"Total elapsed time: [bold blue]{elapsed_seconds:.2}s[/bold blue]")
 
 
 @app.command(
